@@ -57,21 +57,22 @@ def _8(gr: ft.GrowthRates) -> pd.DataFrame:
 @plugin.register_transformer
 def _9(data: pd.DataFrame) -> ft.Fluxes:
     ef = ft.Fluxes()
-    data.to_parquet(str(ef))
+    data.to_csv(str(ef), index=False)
     return ef
 
 
 @plugin.register_transformer
 def _10(ef: ft.Fluxes) -> pd.DataFrame:
-    return pd.read_parquet(str(ef))
+    return pd.read_csv(str(ef), index_col=False)
 
 
 @plugin.register_transformer
 def _11(res: ft.MicomResultsDirectory) -> ft.MicomResultsData:
     return ft.MicomResultsData(
-        exchange_fluxes=pd.read_parquet(str(res.exchange_fluxes.path_maker())),
-        growth_rates=pd.read_csv(
-            str(res.growth_rates.path_maker()), index_col=False)
+        exchange_fluxes=pd.read_csv(
+            str(res.exchange_fluxes.path_maker()), index_col=False
+        ),
+        growth_rates=pd.read_csv(str(res.growth_rates.path_maker()), index_col=False),
     )
 
 
@@ -92,7 +93,7 @@ def _14(rd: ft.MicomResultsDirectory) -> GrowthResults:
     gr = GrowthResults(
         rd.growth_rates.view(pd.DataFrame),
         rd.exchange_fluxes.view(pd.DataFrame),
-        rd.annotations.view(pd.DataFrame)
+        rd.annotations.view(pd.DataFrame),
     )
     return gr
 
@@ -100,8 +101,7 @@ def _14(rd: ft.MicomResultsDirectory) -> GrowthResults:
 @plugin.register_transformer
 def _15(gr: GrowthResults) -> ft.MicomResultsDirectory:
     rd = ft.MicomResultsDirectory()
-    gr["growth_rates"].to_csv(rd.growth_rates.path_maker(), index_col=False)
-    gr["annotations"].to_csv(rd.annotations.path_maker(), index_col=False)
-    gr["exchanges"].to_parquet(rd.exchange_fluxes.path_maker())
+    gr["growth_rates"].to_csv(rd.growth_rates.path_maker(), index=False)
+    gr["annotations"].to_csv(rd.annotations.path_maker(), index=False)
+    gr["exchanges"].to_csv(rd.exchange_fluxes.path_maker(), index=False)
     return rd
-
