@@ -9,14 +9,10 @@ import q2_micom as q2m
 
 this_dir = q2m.tests.this_dir
 
-medium = q2.Artifact.load(path.join(this_dir, "data", "medium.qza")).view(
-    pd.DataFrame
-)
+medium = q2.Artifact.load(path.join(this_dir, "data", "medium.qza")).view(pd.DataFrame)
 models = q2.Artifact.load(path.join(this_dir, "data", "build.qza"))
 
-res = q2m.tradeoff(
-    models.view(q2m._formats_and_types.CommunityModelDirectory),
-    medium)
+res = q2m.tradeoff(models.view(q2m._formats_and_types.CommunityModelDirectory), medium)
 
 
 def test_tradeoff_values():
@@ -28,7 +24,7 @@ def test_tradeoff_values():
 def test_growth_rates():
     low = res.growth_rate[res.tradeoff == 0.1]
     high = res.growth_rate[res.tradeoff == 1.0]
-    assert(low.sum() < high.sum())
+    assert low.sum() < high.sum()
 
 
 def test_sane_tradeoff():
@@ -37,5 +33,5 @@ def test_sane_tradeoff():
             models.view(q2m._formats_and_types.CommunityModelDirectory),
             medium,
             tradeoff_min=0.5,
-            tradeoff_max=0.4
+            tradeoff_max=0.4,
         )
